VapController class

Constructors

VapController({bool autoPlay = false, bool looping = false, VapPlayerPlatform? platform})

Properties

autoPlay bool
final
clickEvents Stream<VapResourceClickEvent>
no setter
hashCode int
The hash code for this object.
no setterinherited
isAttached bool
no setter
looping bool
no setter
playbackEvents Stream<VapPlaybackEvent>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewId int?
no setter

Methods

attach(int viewId) → void
dispose() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onViewDetached() → void
onViewDisposed() Future<void>
pause() Future<void>
play({required VapSourceType sourceType, required String source, String? assetPackage, int? repeatCount, bool mute = false, VapContentMode contentMode = VapContentMode.scaleToFill, int? fps, bool frameEventsEnabled = false, Map<String, String> tagValues = const <String, String>{}}) Future<void>
playAsset(String assetPath, {String? assetPackage, int? repeatCount, bool mute = false, VapContentMode contentMode = VapContentMode.scaleToFill, int? fps, bool frameEventsEnabled = false, Map<String, String> tagValues = const <String, String>{}}) Future<void>
playFile(String filePath, {int? repeatCount, bool mute = false, VapContentMode contentMode = VapContentMode.scaleToFill, int? fps, bool frameEventsEnabled = false, Map<String, String> tagValues = const <String, String>{}}) Future<void>
playNetwork(String url, {int? repeatCount, bool mute = false, VapContentMode contentMode = VapContentMode.scaleToFill, int? fps, bool frameEventsEnabled = false, Map<String, String> tagValues = const <String, String>{}}) Future<void>
resume() Future<void>
setContentMode(VapContentMode mode) Future<void>
setFrameEventsEnabled(bool enabled) Future<void>
setImageResolver(VapImageResolver? resolver) → void
setLooping(bool looping) → void
setMute(bool mute) Future<void>
stop() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited