VapPlaybackEvent class final

Inheritance

Constructors

VapPlaybackEvent({required VapPlaybackEventType type, int? frameIndex, int? width, int? height, int? fps, bool? isMix, int? errorCode, String? errorMessage})
const

Properties

errorCode int?
final
errorMessage String?
final
fps int?
final
frameIndex int?
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
isMix bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type VapPlaybackEventType
final
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited